#!/bin/sh
# ********************************************************************
# @(#) npr/binsrc/admin/check_size.sh npr_d3.6.0.20:cset.005742:6:6@(#)
#
# FILENAME : npr/binsrc/admin/check_size.sh
#
# ********************************************************************
#
#                   COPYRIGHT NOTICE
#
# This file remains the intellectual property of:
#
#              Vallent Software Systems UK
#                    Spencer House
#                    23 Sheen Road
#                 Richmond, Surrey, UK
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
#
# ********************************************************************
# NPR Admin

# ------------------------------------------------------------------------------
# Function F_exit 
# ------------------------------------------------------------------------------
F_exit()     # Error number, info+
{
  v_err=$1               # Error Number
  v_info=$2              # Error Information
  v_mess=""              # Init the error message
 
  case $v_err in
    0)  v_mess="";;
    1)  F_usage
        v_mess="Err  1 : Usage error ($v_info)" ;;
    2)  v_mess="Err  2 : Missing the file $v_info";;
    3)  v_mess="Err  3 : TSL script failed (return=$v_info)";;
    4)  v_mess="Err  4 : TSL LOAD transfert failed (return=$v_info)";;
   10)  v_mess="Err 10 : Received signal $v_info, terminating";;
    *)  v_mess="Err $v_err - Text : $v_info";;
  esac

  # Delete the tmp file
  # -------------------
  rm -f $NPR_TMP_DIR/*.$$

  if [ ! -z "$v_mess" ] ; then
    echo ""
    echo "$v_mess" >&2
  fi

  exit $v_err                  # Exit with status
}

# ------------------------------------------------------------------------------
# Function F_usage
# ------------------------------------------------------------------------------
F_usage()
{
  usage="Usage : check_size.sh -db <database> [-file <name>] [-keepday <num>] \n\
                     [-help|-usage] \n\
         \n\
         Update the S_SIZE statistic table in the admin database or create a file \n\
         with the following information : \n\
           path, file, volume, table, db, type, age, day, rows, theory, actual \n\
        \n\
           -db <database>      : Database name \n\
           [-file <filename>]  : File name (Output) \n\
                                 the default output is the table S_SIZE. \n\
           [-help|-usage]      : Display this message \n\
           [-keepday <num>]    : Delete the days for the database older than \n\
                                 the parameter in the table S_SIZE.\n\
           \n\
           e.g.   check_size.sh -db NPRDB \n\
                  check_size.sh -db NPRDB -file /tmp/size.perf \n\
           \n\
                From the crontab \n\
                  25 9 * * * check_size.sh -db NPRDB -keepday 120 " 

  echo ""
  echo "$usage" >&2
}

# ------------------------------------------------------------------------------
# Function F_check_actualsize_and_age
# ------------------------------------------------------------------------------
F_check_actualsize_and_age()
{
  v_save_IFS=$IFS
  IFS=";"

  cat $v_wkfile | while read v_dir v_file v_loc v_table v_db v_type v_age v_day v_rows v_theory v_actual
  do
    v_actual=`ls -l $v_dir/$v_file | $NPR_NAWK '{print $5}' `

    v_age=`$NPR_NAWK -v p_table="$v_table" -F";" '{if ($1==p_table) {print $2;exit}}' $v_agefile`
    if [ "$v_age" = "" ] ; then
      v_age="0D"
    fi

    echo "$v_dir;$v_file;$v_loc;$v_table;$v_db;$v_type;$v_age;$v_day;$v_rows;$v_theory;$v_actual" >> $v_resfile
  done

  IFS=$v_save_IFS
}


# ------------------------------------------------------------------------------
# Main
# ------------------------------------------------------------------------------
trap 'F_exit 10 HUP'   1
trap 'F_exit 10 INT'   2
trap 'F_exit 10 QUIT'  3
trap 'F_exit 10 TERM' 15

# Check the Parameters
#
v_filename=""
v_dbname=""
v_keepday=-1

while [ $# -gt 0 ]
do
  case "$1" in
        -help) F_usage
               F_exit 0
               ;;
       -usage) F_usage
               F_exit 0
               ;;
          -db) v_dbname=$2
               shift 2
               ;;
        -file) v_filename=$2
               shift 2
               ;;
     -keepday) v_keepday=$2
               shift 2
               ;;
           --) shift
               break
               ;;
            *) F_exit 1 "$1"
               ;;
  esac
done

if [ "$v_dbname" = "" ] ; then
  F_exit 1 "Need a database name"
fi

# Read in lots of important environment variables.
#
if [ -r $NPR_DIR/etc/env ] ; then
  . $NPR_DIR/etc/env
else
  F_exit 2 "NPR_DIR/etc/env"
fi

# Variables
#
v_wkfile=$NPR_TMP_DIR/sizedb.$$
v_agefile=$NPR_TMP_DIR/sizedb.age.$$
v_resfile=$NPR_TMP_DIR/sizedb.result.$$

# Query to extract the age in the ARCHIVE table
#
tsl $NPR_TSLOPTS -nowin -user ARCHIVER size_age.tsl "$NPR_ADMIN_DB" "$v_agefile"
v_return=$?
if [ $v_return -ne 0 ] ; then
  F_exit 3 "$v_return"
fi

# Query to extract the theoretical size (table and indexes)  
# 
#For bug 31201
# Acquire the password from the environment
tsl $NPR_TSLOPTS -nowin -user GUEST size_db.tsl "$v_dbname" "$v_wkfile"
v_return=$?
if [ $v_return -ne 0 ] ; then
  F_exit 3 "$v_return"
fi

# Now check the actual size (table and indexes)
#
F_check_actualsize_and_age

# Put the result in : the statistic table or in a file
#
if [ "$v_filename" = "" ] ; then
  # Insert in the database
  #
  tsl $NPR_TSLOPTS -nowin -user GUEST ins_sizedata.tsl "$NPR_ADMIN_DB" "$v_resfile" "$v_keepday"
  v_return=$?
  if [ $v_return -ne 0 ] ; then
    F_exit 4 "$v_return"
  fi
else
  # Output in the file
  #
  mv "$v_resfile" "$v_filename"
fi

F_exit 0
