#!/bin/sh
# *************************************************************************
#
# @(#) npr/upgrade/upgrade3.6.0_fp1/ug_ctmcol/upg_timecol.sh npr_d3.6.0.20:aset.006011:1:1@(#)
#
# FILENAME:  npr/upgrade/upgrade3.6.0_fp1/ug_ctmcol/upg_timecol.sh
#
# *************************************************************************
#                   COPYRIGHT NOTICE
#
# This file remains the intellectual property of:
#
#              Vallent Software System UK
#                    Spencer House
#                    23 Sheen Road
#                 Richmond, Surrey, UK.
#
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
# *************************************************************************
#
# Shell script to add the C_TMCOL table to Performance Database


workDir=`pwd`
scriptFile="./upg_timecol.tsl"
logFile="./upg_timecol.log"
export logFile

usage()
{
  echo ""
  echo "Script for creating Metrica / NPR C_TMCOL table."
  echo "For use with Metrica / NPR 3.6.0_fp1 upwards only"
  echo "Usage: ./upg_timecol.sh -database dbname -user username -password password"
  echo ""
}

version()
{
  echo ""
  echo "npr_d3.6.0.20:aset.006011:1:1"
  echo ""
}

handleArgs()
{

  if [ $# -eq 0 ]
  then
    usage
    exit 1
  fi

  while [ $# -gt 0 ]
  do
    case $1 in
      -help|-h)     usage
                    closeLog $*
                    exit 0;;
      -version|-v)  version
                    closeLog $*
                    exit 0;;
      -database)    NPR_DB=$2
                    shift 2;;
      -user|-u)     NPR_USER=$2
                    shift 2;;
      -password|-p) NPR_PASSWORD=$2
                    shift 2;;
      *)            usage
                    closeLog $*
                    exit 1;;
    esac
  done

  if [ -z "$NPR_PASSWORD" ]
  then
    echo ""
    echo  "Enter Password: \c"
    stty_orig=`stty -g`
    stty -echo # stop password being displayed
    read NPR_PASSWORD
    stty $stty_orig
    echo ""
  fi

  if [ -z "$NPR_DB" ]
  then
    echo "Error: -database not set"
    log "Error: -database not set"
    do_exit=1
  fi
  if [ -z "$NPR_USER" ]
  then
    echo "Error: -user not set"
    log "Error: -user not set"
    do_exit=1
  fi
  if [ -z "$NPR_PASSWORD" ]
  then
    echo "Error: -password not set"
    log "Error: -password not set"
    do_exit=1
  fi

  if [ $do_exit ]
  then
    closeLog $*
    exit 1
  fi

  export NPR_DB
  export NPR_USER
  export NPR_PASSWORD

}

welcome()
{

  echo ""
  echo "#************************************************************************"
  echo "#                   COPYRIGHT NOTICE                            	#"
  echo "#                                                               	#"
  echo "# This utility remains the intellectual property of:            	#"
  echo "#                                                               	#"
  echo "#              Vallent Software System UK				#"
  echo "#                    Spencer House					#"
  echo "#                    23 Sheen Road					#"
  echo "#                 Richmond, Surrey, UK.					#"
  echo "#									#"
  echo "# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.	#"
  echo "#************************************************************************"
  echo ""
  echo "#************************************************************************"
  echo "*                                                               *********"
  echo "* Metrica / NPR C_TMCOL Table Create Utility                    *********"
  echo "*                                                               *********"
  echo "* Part of the upgrade for Metrica/NPR 3.6.0_fp1 upwards         *********"
  echo "*                                                               *********"
  echo "#************************************************************************"
  echo ""
}

log()
{
  echo "$1" >> $logFile

}

openLog()
{
  log "===> [$$] $0 $* started on `date` by `whoami` <===\n"
}

closeLog()
{
  log  "===> [$$] $0 $* completed on `date` <==="
  echo "See $logFile for saved output."
}

##################################
# main
##################################

welcome

openLog $*

handleArgs $*

# Run qtip with script to update database
env >> $logFile
tsl -version 2>> $logFile
echo "Running $scriptFile...\n"
eval tsl -nowin -user $NPR_USER $scriptFile 2>> $logFile
if [ $? -ne 0 ]
then
  echo "Error: Could not successfully run upg_timecol.tsl, check log file.\n" >&2
  exit 3
fi

echo ""
echo "Completed."
echo ""
closeLog "$*"
